summaryrefslogtreecommitdiffstats
path: root/chrome/browser/location_bar.h
diff options
context:
space:
mode:
authorbulach@chromium.org <bulach@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-03-05 11:40:08 +0000
committerbulach@chromium.org <bulach@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-03-05 11:40:08 +0000
commit352104ee28f47810b5d2dc5fd6193c60d2cd2e95 (patch)
tree1d4d26928b9951a3d5f54688c550835740849837 /chrome/browser/location_bar.h
parentff039f0833a278d7ca80aeb8987e73b6c258f305 (diff)
downloadchromium_src-352104ee28f47810b5d2dc5fd6193c60d2cd2e95.zip
chromium_src-352104ee28f47810b5d2dc5fd6193c60d2cd2e95.tar.gz
chromium_src-352104ee28f47810b5d2dc5fd6193c60d2cd2e95.tar.bz2
Renames ContentBlockedImageView to ContentSettingImageView.
Adds ContentSettingImageModel to provide icon and tooltips for platform-specific ContentBlockedImageView. (in preparation for: http://codereview.chromium.org/650180/show ) TEST=chrome/browser/content_setting_image_model_unittest.cc Review URL: http://codereview.chromium.org/660279 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@40732 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/location_bar.h')
-rw-r--r--chrome/browser/location_bar.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/browser/location_bar.h b/chrome/browser/location_bar.h
index 9d0a49c..29bfddc 100644
--- a/chrome/browser/location_bar.h
+++ b/chrome/browser/location_bar.h
@@ -50,8 +50,8 @@ class LocationBar {
// focus to it.
virtual void FocusSearch() = 0;
- // Updates the state of the images showing what content was blocked.
- virtual void UpdateContentBlockedIcons() = 0;
+ // Updates the state of the images showing the content settings status.
+ virtual void UpdateContentSettingsIcons() = 0;
// Updates the state of the page actions.
virtual void UpdatePageActions() = 0;